Learn R Programming

happybiRthday (version 0.0.1)

celebrate: Celebrating software birthdays

Description

Accesses all public repositories belonging to a specific Github user and prints each repository's respective name, age, creation date of initial commit (i.e., repository birthday date), and time remaining until upcoming birthday.

Usage

celebrate(github_username)

Arguments

github_username

Character vector of one Github username handle (e.g., "some_username_here").

Value

Returns data frame with repository name, age, creation date, and time remaining until upcoming birthday.

Examples

Run this code
# NOT RUN {
celebrate("Bohdan-Khomtchouk")

# }

Run the code above in your browser using DataLab